Play the Game of Nim
====================

.. .. toctree::
    :maxdepth: 2
    :caption: Contents

    README.rst

.. Get the docstring from the package level __init__.py
.. No members, to avoid e.g. __init__.Nim
.. automodule:: __init__
    :no-members:

.. automodule:: tests.testruns
    :members:
